==> jc-1.4.0.tar.gz: soot/tools/BadFields.h <==
// public class soot.tools.BadFields

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 75b5801009937b64 soot_tools_BadFields

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_tools_BadFields_H_
#define _JC_soot_tools_BadFields_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_tools_BadFields$sub_refs	_jc_soot_tools_BadFields$sub_refs;
typedef struct _jc_soot_tools_BadFields$sub_nonrefs	_jc_soot_tools_BadFields$sub_nonrefs;
typedef struct _jc_soot_tools_BadFields$refs	_jc_soot_tools_BadFields$refs;
typedef struct _jc_soot_tools_BadFields$nonrefs	_jc_soot_tools_BadFields$nonrefs;
typedef struct _jc_soot_tools_BadFields$object	_jc_soot_tools_BadFields$object;

typedef const struct _jc_soot_tools_BadFields$vmethods	_jc_soot_tools_BadFields$vmethods;
typedef const struct _jc_soot_tools_BadFields$vtable	_jc_soot_tools_BadFields$vtable;
typedef const struct _jc_soot_tools_BadFields$vtype	_jc_soot_tools_BadFields$vtype;

// Constructors
extern void _jc_soot_tools_BadFields$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tools_BadFields$object *);

// Virtual methods
extern void _jc_soot_tools_BadFields$method$calls$ae10d8dc9fc76f1f(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_tools_BadFields$method$handleClass$bf8747bfb77edb12(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootClass$object *);
extern void _jc_soot_tools_BadFields$method$handleMethod$5ad76532476427b4(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *);
extern void _jc_soot_tools_BadFields$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
extern void _jc_soot_tools_BadFields$method$warn$50b831308855e5e5(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tools_BadFields$method_info$calls$ae10d8dc9fc76f1f;
extern _jc_method _jc_soot_tools_BadFields$method_info$handleClass$bf8747bfb77edb12;
extern _jc_method _jc_soot_tools_BadFields$method_info$handleMethod$5ad76532476427b4;
extern _jc_method _jc_soot_tools_BadFields$method_info$internalTransform$b44b61d0d9f22a06;
extern _jc_method _jc_soot_tools_BadFields$method_info$warn$50b831308855e5e5;

// Static methods
extern void _jc_soot_tools_BadFields$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_soot_tools_BadFields$vmethods {
	void	(*calls$ae10d8dc9fc76f1f)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *);
	void	(*handleClass$bf8747bfb77edb12)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootClass$object *);
	void	(*handleMethod$5ad76532476427b4)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *);
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
	void	(*warn$50b831308855e5e5)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_soot_tools_BadFields$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_tools_BadFields$vmethods	soot_tools_BadFields;
};

// Vtype
struct _jc_soot_tools_BadFields$vtype {
	_jc_type			type;
	_jc_soot_tools_BadFields$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tools_BadFields$sub_refs {
	struct _jc_soot_SootClass$object	*lastClass;
	struct _jc_soot_SootClass$object	*currentClass;
};

// Reference instance fields (object)
struct _jc_soot_tools_BadFields$refs {
    _jc_soot_tools_BadFields$sub_refs	soot_tools_BadFields;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tools_BadFields$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tools_BadFields$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_tools_BadFields$sub_nonrefs	soot_tools_BadFields;
};

// Object instance structure
struct _jc_soot_tools_BadFields$object {
	_jc_soot_tools_BadFields$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tools_BadFields$vtype	*vtype;
	_jc_soot_tools_BadFields$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tools_BadFields$vtype _jc_soot_tools_BadFields$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tools_BadFields, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tools_BadFields$class_object;

#endif	/* _JC_soot_tools_BadFields_H_ */

==> jc-1.4.6.tar.gz: soot/tools/BadFields.h <==
// public class soot.tools.BadFields

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1988ae632461b86a soot_SceneTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 75b5801009937b64 soot_tools_BadFields

// header file dependencies
// @dep_header soot_SceneTransformer

#include "soot/SceneTransformer.h"

#ifndef _JC_soot_tools_BadFields_H_
#define _JC_soot_tools_BadFields_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_SootClass$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_tools_BadFields$sub_refs	_jc_soot_tools_BadFields$sub_refs;
typedef struct _jc_soot_tools_BadFields$sub_nonrefs	_jc_soot_tools_BadFields$sub_nonrefs;
typedef struct _jc_soot_tools_BadFields$refs	_jc_soot_tools_BadFields$refs;
typedef struct _jc_soot_tools_BadFields$nonrefs	_jc_soot_tools_BadFields$nonrefs;
typedef struct _jc_soot_tools_BadFields$object	_jc_soot_tools_BadFields$object;

typedef const struct _jc_soot_tools_BadFields$vmethods	_jc_soot_tools_BadFields$vmethods;
typedef const struct _jc_soot_tools_BadFields$vtable	_jc_soot_tools_BadFields$vtable;
typedef const struct _jc_soot_tools_BadFields$vtype	_jc_soot_tools_BadFields$vtype;

// Constructors
extern void _jc_soot_tools_BadFields$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tools_BadFields$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_tools_BadFields$method$calls$ae10d8dc9fc76f1f(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_tools_BadFields$method$handleClass$bf8747bfb77edb12(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
extern void _jc_soot_tools_BadFields$method$handleMethod$5ad76532476427b4(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
extern void _jc_soot_tools_BadFields$method$internalTransform$b44b61d0d9f22a06(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_tools_BadFields$method$warn$50b831308855e5e5(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tools_BadFields$method_info$calls$ae10d8dc9fc76f1f;
extern _jc_method _jc_soot_tools_BadFields$method_info$handleClass$bf8747bfb77edb12;
extern _jc_method _jc_soot_tools_BadFields$method_info$handleMethod$5ad76532476427b4;
extern _jc_method _jc_soot_tools_BadFields$method_info$internalTransform$b44b61d0d9f22a06;
extern _jc_method _jc_soot_tools_BadFields$method_info$warn$50b831308855e5e5;

// Static methods
extern void _jc_soot_tools_BadFields$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_tools_BadFields$vmethods {
	void	(*calls$ae10d8dc9fc76f1f)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*handleClass$bf8747bfb77edb12)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;
	void	(*handleMethod$5ad76532476427b4)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_soot_SootMethod$object *) _JC_JCNI_ATTR;
	void	(*internalTransform$b44b61d0d9f22a06)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*warn$50b831308855e5e5)(_jc_env *, struct _jc_soot_tools_BadFields$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tools_BadFields$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_SceneTransformer$vmethods	soot_SceneTransformer;
	_jc_soot_tools_BadFields$vmethods	soot_tools_BadFields;
};

// Vtype
struct _jc_soot_tools_BadFields$vtype {
	_jc_type			type;
	_jc_soot_tools_BadFields$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tools_BadFields$sub_refs {
	struct _jc_soot_SootClass$object	*lastClass;
	struct _jc_soot_SootClass$object	*currentClass;
};

// Reference instance fields (object)
struct _jc_soot_tools_BadFields$refs {
    _jc_soot_tools_BadFields$sub_refs	soot_tools_BadFields;
    _jc_soot_SceneTransformer$sub_refs	soot_SceneTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tools_BadFields$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tools_BadFields$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_SceneTransformer$sub_nonrefs	soot_SceneTransformer;
    _jc_soot_tools_BadFields$sub_nonrefs	soot_tools_BadFields;
};

// Object instance structure
struct _jc_soot_tools_BadFields$object {
	_jc_soot_tools_BadFields$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tools_BadFields$vtype	*vtype;
	_jc_soot_tools_BadFields$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tools_BadFields$vtype _jc_soot_tools_BadFields$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tools_BadFields, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tools_BadFields$class_object;

#endif	/* _JC_soot_tools_BadFields_H_ */
